==> crd-annotations-0.14.2-sources.jar: io/dekorate/crd/config/CustomResourceConfigFluentImpl.java <==
package io.dekorate.crd.config;

import io.dekorate.kubernetes.config.ConfigurationFluentImpl;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceConfigFluentImpl<A extends CustomResourceConfigFluent<A>> extends ConfigurationFluentImpl<A> implements CustomResourceConfigFluent<A> {

    private String group;
    private String kind;
    private String name;
    private String plural;
    private String shortName;
    private String version;
    private Scope scope;
    private ScaleBuilder scale;
    private String statusClassName;

    public CustomResourceConfigFluentImpl() { 
    }


    public CustomResourceConfigFluentImpl(CustomResourceConfig instance) { 
        this.withProject(instance.getProject()); 
        this.withAttributes(instance.getAttributes()); 
        this.withGroup(instance.getGroup()); 
        this.withKind(instance.getKind()); 
        this.withName(instance.getName()); 
        this.withPlural(instance.getPlural()); 
        this.withShortName(instance.getShortName()); 
        this.withVersion(instance.getVersion()); 
        this.withScope(instance.getScope()); 
        this.withScale(instance.getScale()); 
        this.withStatusClassName(instance.getStatusClassName()); 
    }


    public String getGroup() {
        return this.group;
    }

    public A withGroup(String group) {
        this.group=group; return (A) this;
    }

    public Boolean hasGroup() {
        return this.group != null;
    }

    public A withNewGroup(String arg1) {
        return (A)withGroup(new String(arg1));
    }

    public A withNewGroup(StringBuilder arg1) {
        return (A)withGroup(new String(arg1));
    }

    public A withNewGroup(StringBuffer arg1) {
        return (A)withGroup(new String(arg1));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public String getPlural() {
        return this.plural;
    }

    public A withPlural(String plural) {
        this.plural=plural; return (A) this;
    }

    public Boolean hasPlural() {
        return this.plural != null;
    }

    public A withNewPlural(String arg1) {
        return (A)withPlural(new String(arg1));
    }

    public A withNewPlural(StringBuilder arg1) {
        return (A)withPlural(new String(arg1));
    }

    public A withNewPlural(StringBuffer arg1) {
        return (A)withPlural(new String(arg1));
    }

    public String getShortName() {
        return this.shortName;
    }

    public A withShortName(String shortName) {
        this.shortName=shortName; return (A) this;
    }

    public Boolean hasShortName() {
        return this.shortName != null;
    }

    public A withNewShortName(String arg1) {
        return (A)withShortName(new String(arg1));
    }

    public A withNewShortName(StringBuilder arg1) {
        return (A)withShortName(new String(arg1));
    }

    public A withNewShortName(StringBuffer arg1) {
        return (A)withShortName(new String(arg1));
    }

    public String getVersion() {
        return this.version;
    }

    public A withVersion(String version) {
        this.version=version; return (A) this;
    }

    public Boolean hasVersion() {
        return this.version != null;
    }

    public A withNewVersion(String arg1) {
        return (A)withVersion(new String(arg1));
    }

    public A withNewVersion(StringBuilder arg1) {
        return (A)withVersion(new String(arg1));
    }

    public A withNewVersion(StringBuffer arg1) {
        return (A)withVersion(new String(arg1));
    }

    public Scope getScope() {
        return this.scope;
    }

    public A withScope(Scope scope) {
        this.scope=scope; return (A) this;
    }

    public Boolean hasScope() {
        return this.scope != null;
    }

    
/**
 * This method has been deprecated, please use method buildScale instead.
 * @return The buildable object.
 */
@Deprecated public Scale getScale() {
        return this.scale!=null?this.scale.build():null;
    }

    public Scale buildScale() {
        return this.scale!=null?this.scale.build():null;
    }

    public A withScale(Scale scale) {
        _visitables.get("scale").remove(this.scale);
        if (scale!=null){ this.scale= new ScaleBuilder(scale); _visitables.get("scale").add(this.scale);} return (A) this;
    }

    public Boolean hasScale() {
        return this.scale != null;
    }

    public A withNewScale(String specReplicasPath,String statusReplicasPath,String labelSelectorPath) {
        return (A)withScale(new Scale(specReplicasPath, statusReplicasPath, labelSelectorPath));
    }

    public CustomResourceConfigFluent.ScaleNested<A> withNewScale() {
        return new ScaleNestedImpl();
    }

    public CustomResourceConfigFluent.ScaleNested<A> withNewScaleLike(Scale item) {
        return new ScaleNestedImpl(item);
    }

    public CustomResourceConfigFluent.ScaleNested<A> editScale() {
        return withNewScaleLike(getScale());
    }

    public CustomResourceConfigFluent.ScaleNested<A> editOrNewScale() {
        return withNewScaleLike(getScale() != null ? getScale(): new ScaleBuilder().build());
    }

    public CustomResourceConfigFluent.ScaleNested<A> editOrNewScaleLike(Scale item) {
        return withNewScaleLike(getScale() != null ? getScale(): item);
    }

    public String getStatusClassName() {
        return this.statusClassName;
    }

    public A withStatusClassName(String statusClassName) {
        this.statusClassName=statusClassName; return (A) this;
    }

    public Boolean hasStatusClassName() {
        return this.statusClassName != null;
    }

    public A withNewStatusClassName(String arg1) {
        return (A)withStatusClassName(new String(arg1));
    }

    public A withNewStatusClassName(StringBuilder arg1) {
        return (A)withStatusClassName(new String(arg1));
    }

    public A withNewStatusClassName(StringBuffer arg1) {
        return (A)withStatusClassName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceConfigFluentImpl that = (CustomResourceConfigFluentImpl) o;
        if (group != null ? !group.equals(that.group) :that.group != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        if (plural != null ? !plural.equals(that.plural) :that.plural != null) return false;
        if (shortName != null ? !shortName.equals(that.shortName) :that.shortName != null) return false;
        if (version != null ? !version.equals(that.version) :that.version != null) return false;
        if (scope != null ? !scope.equals(that.scope) :that.scope != null) return false;
        if (scale != null ? !scale.equals(that.scale) :that.scale != null) return false;
        if (statusClassName != null ? !statusClassName.equals(that.statusClassName) :that.statusClassName != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(group,  kind,  name,  plural,  shortName,  version,  scope,  scale,  statusClassName,  super.hashCode());
    }

    public class ScaleNestedImpl<N> extends ScaleFluentImpl<CustomResourceConfigFluent.ScaleNested<N>> implements CustomResourceConfigFluent.ScaleNested<N>,Nested<N> {
        private final ScaleBuilder builder;

        ScaleNestedImpl(Scale item) {
            this.builder = new ScaleBuilder(this, item);
        }

        ScaleNestedImpl() {
            this.builder = new ScaleBuilder(this);
        }

        public N and() {
             return (N) CustomResourceConfigFluentImpl.this.withScale(builder.build());
        }

        public N endScale() {
             return and();
        }
    }


}

==> crd-annotations-0.15.0-sources.jar: io/dekorate/crd/config/CustomResourceConfigFluentImpl.java <==
package io.dekorate.crd.config;

import io.dekorate.kubernetes.config.ConfigurationFluentImpl;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceConfigFluentImpl<A extends CustomResourceConfigFluent<A>> extends ConfigurationFluentImpl<A> implements CustomResourceConfigFluent<A> {

    private String group;
    private String kind;
    private String name;
    private String plural;
    private String shortName;
    private String version;
    private boolean served;
    private boolean storage;
    private Scope scope;
    private ScaleBuilder scale;
    private String statusClassName;

    public CustomResourceConfigFluentImpl() { 
    }


    public CustomResourceConfigFluentImpl(CustomResourceConfig instance) { 
        this.withProject(instance.getProject()); 
        this.withAttributes(instance.getAttributes()); 
        this.withGroup(instance.getGroup()); 
        this.withKind(instance.getKind()); 
        this.withName(instance.getName()); 
        this.withPlural(instance.getPlural()); 
        this.withShortName(instance.getShortName()); 
        this.withVersion(instance.getVersion()); 
        this.withServed(instance.isServed()); 
        this.withStorage(instance.isStorage()); 
        this.withScope(instance.getScope()); 
        this.withScale(instance.getScale()); 
        this.withStatusClassName(instance.getStatusClassName()); 
    }


    public String getGroup() {
        return this.group;
    }

    public A withGroup(String group) {
        this.group=group; return (A) this;
    }

    public Boolean hasGroup() {
        return this.group != null;
    }

    public A withNewGroup(String arg1) {
        return (A)withGroup(new String(arg1));
    }

    public A withNewGroup(StringBuilder arg1) {
        return (A)withGroup(new String(arg1));
    }

    public A withNewGroup(StringBuffer arg1) {
        return (A)withGroup(new String(arg1));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public String getPlural() {
        return this.plural;
    }

    public A withPlural(String plural) {
        this.plural=plural; return (A) this;
    }

    public Boolean hasPlural() {
        return this.plural != null;
    }

    public A withNewPlural(String arg1) {
        return (A)withPlural(new String(arg1));
    }

    public A withNewPlural(StringBuilder arg1) {
        return (A)withPlural(new String(arg1));
    }

    public A withNewPlural(StringBuffer arg1) {
        return (A)withPlural(new String(arg1));
    }

    public String getShortName() {
        return this.shortName;
    }

    public A withShortName(String shortName) {
        this.shortName=shortName; return (A) this;
    }

    public Boolean hasShortName() {
        return this.shortName != null;
    }

    public A withNewShortName(String arg1) {
        return (A)withShortName(new String(arg1));
    }

    public A withNewShortName(StringBuilder arg1) {
        return (A)withShortName(new String(arg1));
    }

    public A withNewShortName(StringBuffer arg1) {
        return (A)withShortName(new String(arg1));
    }

    public String getVersion() {
        return this.version;
    }

    public A withVersion(String version) {
        this.version=version; return (A) this;
    }

    public Boolean hasVersion() {
        return this.version != null;
    }

    public A withNewVersion(String arg1) {
        return (A)withVersion(new String(arg1));
    }

    public A withNewVersion(StringBuilder arg1) {
        return (A)withVersion(new String(arg1));
    }

    public A withNewVersion(StringBuffer arg1) {
        return (A)withVersion(new String(arg1));
    }

    public boolean isServed() {
        return this.served;
    }

    public A withServed(boolean served) {
        this.served=served; return (A) this;
    }

    public Boolean hasServed() {
        return true;
    }

    public boolean isStorage() {
        return this.storage;
    }

    public A withStorage(boolean storage) {
        this.storage=storage; return (A) this;
    }

    public Boolean hasStorage() {
        return true;
    }

    public Scope getScope() {
        return this.scope;
    }

    public A withScope(Scope scope) {
        this.scope=scope; return (A) this;
    }

    public Boolean hasScope() {
        return this.scope != null;
    }

    
/**
 * This method has been deprecated, please use method buildScale instead.
 * @return The buildable object.
 */
@Deprecated public Scale getScale() {
        return this.scale!=null?this.scale.build():null;
    }

    public Scale buildScale() {
        return this.scale!=null?this.scale.build():null;
    }

    public A withScale(Scale scale) {
        _visitables.get("scale").remove(this.scale);
        if (scale!=null){ this.scale= new ScaleBuilder(scale); _visitables.get("scale").add(this.scale);} return (A) this;
    }

    public Boolean hasScale() {
        return this.scale != null;
    }

    public A withNewScale(String specReplicasPath,String statusReplicasPath,String labelSelectorPath) {
        return (A)withScale(new Scale(specReplicasPath, statusReplicasPath, labelSelectorPath));
    }

    public CustomResourceConfigFluent.ScaleNested<A> withNewScale() {
        return new ScaleNestedImpl();
    }

    public CustomResourceConfigFluent.ScaleNested<A> withNewScaleLike(Scale item) {
        return new ScaleNestedImpl(item);
    }

    public CustomResourceConfigFluent.ScaleNested<A> editScale() {
        return withNewScaleLike(getScale());
    }

    public CustomResourceConfigFluent.ScaleNested<A> editOrNewScale() {
        return withNewScaleLike(getScale() != null ? getScale(): new ScaleBuilder().build());
    }

    public CustomResourceConfigFluent.ScaleNested<A> editOrNewScaleLike(Scale item) {
        return withNewScaleLike(getScale() != null ? getScale(): item);
    }

    public String getStatusClassName() {
        return this.statusClassName;
    }

    public A withStatusClassName(String statusClassName) {
        this.statusClassName=statusClassName; return (A) this;
    }

    public Boolean hasStatusClassName() {
        return this.statusClassName != null;
    }

    public A withNewStatusClassName(String arg1) {
        return (A)withStatusClassName(new String(arg1));
    }

    public A withNewStatusClassName(StringBuilder arg1) {
        return (A)withStatusClassName(new String(arg1));
    }

    public A withNewStatusClassName(StringBuffer arg1) {
        return (A)withStatusClassName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceConfigFluentImpl that = (CustomResourceConfigFluentImpl) o;
        if (group != null ? !group.equals(that.group) :that.group != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        if (plural != null ? !plural.equals(that.plural) :that.plural != null) return false;
        if (shortName != null ? !shortName.equals(that.shortName) :that.shortName != null) return false;
        if (version != null ? !version.equals(that.version) :that.version != null) return false;
        if (served != that.served) return false;
        if (storage != that.storage) return false;
        if (scope != null ? !scope.equals(that.scope) :that.scope != null) return false;
        if (scale != null ? !scale.equals(that.scale) :that.scale != null) return false;
        if (statusClassName != null ? !statusClassName.equals(that.statusClassName) :that.statusClassName != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(group,  kind,  name,  plural,  shortName,  version,  served,  storage,  scope,  scale,  statusClassName,  super.hashCode());
    }

    public class ScaleNestedImpl<N> extends ScaleFluentImpl<CustomResourceConfigFluent.ScaleNested<N>> implements CustomResourceConfigFluent.ScaleNested<N>,Nested<N> {
        private final ScaleBuilder builder;

        ScaleNestedImpl(Scale item) {
            this.builder = new ScaleBuilder(this, item);
        }

        ScaleNestedImpl() {
            this.builder = new ScaleBuilder(this);
        }

        public N and() {
             return (N) CustomResourceConfigFluentImpl.this.withScale(builder.build());
        }

        public N endScale() {
             return and();
        }
    }


}
